==> foundry_platform_sdk-0.49.0.tar.gz: foundry_platform_sdk-0.49.0/foundry/v2/aip_agents/errors/_streaming_continue_session_permission_denied.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

import pydantic
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v2.aip_agents.models._agent_rid import AgentRid
from foundry.v2.aip_agents.models._session_rid import SessionRid


class StreamingContinueSessionPermissionDeniedParameters(TypedDict):
    """Could not streamingContinue the Session."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    agentRid: AgentRid
    """An RID identifying an AIP Agent created in [AIP Agent Studio](/docs/foundry/agent-studio/overview/)."""

    sessionRid: SessionRid
    """The Resource Identifier (RID) of the conversation session."""


@dataclass
class StreamingContinueSessionPermissionDenied(PalantirRPCException):
    name: Literal["StreamingContinueSessionPermissionDenied"]
    parameters: StreamingContinueSessionPermissionDeniedParameters
    error_instance_id: str


__all__ = ["StreamingContinueSessionPermissionDenied"]

==> foundry_platform_sdk-0.90.0.tar.gz: foundry_platform_sdk-0.90.0/foundry/v2/aip_agents/errors/_streaming_continue_session_permission_denied.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

from typing_extensions import TypedDict

from foundry._errors import PermissionDeniedError
from foundry.v2.aip_agents.models._agent_rid import AgentRid
from foundry.v2.aip_agents.models._session_rid import SessionRid


class StreamingContinueSessionPermissionDeniedParameters(TypedDict):
    """Could not streamingContinue the Session."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    agentRid: AgentRid
    """An RID identifying an AIP Agent created in [AIP Agent Studio](/docs/foundry/agent-studio/overview/)."""
    sessionRid: SessionRid
    """The Resource Identifier (RID) of the conversation session."""


@dataclass
class StreamingContinueSessionPermissionDenied(PermissionDeniedError):
    name: Literal["StreamingContinueSessionPermissionDenied"]
    parameters: StreamingContinueSessionPermissionDeniedParameters
    error_instance_id: str


__all__ = ["StreamingContinueSessionPermissionDenied"]
